from flask import Flask, request, jsonify
from flask_cors import CORS
import requests, re, json, os, yaml
from db import *
from aliexpress import *

app = Flask(__name__)
CORS(app)

@app.route('/init', methods = ['GET'])
def init_db():
    status = check_schema()
    if not status:
        initialize()
    return str(status)

@app.route('/update', methods = ['GET'])
def update_hist():
    print("update")
    update_items()
    return 'items updated'

@app.route('/add', methods=['POST'])
def add_item():
    print("adding item")

    data = request.get_json()

    itemid = data.get('itemid')
    attributes = data.get('attributes', '').split(',') if data.get('attributes') else []

    new_item = [itemid, attributes]
    extr = check_item(new_item)

    if len(extr) > 0:
        skuid = list(extr.values())[0]["skuid"]
        if check_exist(itemid, skuid):
            # item already exists
            return jsonify({'status': 3}), 400
        else:
            # item is valid
            fill_db(extr)
            return jsonify({'status': 0}), 200
    else:
        # item not valid or can't be parsed
        return jsonify({'status': 1}), 400

@app.route('/delete', methods=['POST'])
def del_item():
    print("deleting item")
    data = request.get_json()
    uuid = data.get('uuid')
    delete_item(uuid)
    return jsonify({'deleted': uuid}), 200

@app.route('/show', methods=['POST'])
def toggle_item_show():
    data = request.get_json()
    uuid = data.get('uuid')
    toggle_show(uuid)
    return jsonify({'toggled show/hide ': uuid}), 200

@app.route('/datahistory',methods = ['GET'])
def data_history_request():
    if request.method == 'GET':
        print("fetching data history")
        return jsonify(get_history())

@app.route('/dataitem',methods = ['GET'])
def data_item_request():
    if request.method == 'GET':
        print("fetching data item")
        return jsonify(get_item())

if __name__ == '__main__':
   app.run(debug = True)
